@@ -10,7 +10,7 @@ use Readonly;
 # Constants.
 Readonly::Array our @EXPORT => qw(parse_java_jdk_release);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Parse Java JDK release.
 sub parse_java_jdk_release {
@@ -31,6 +31,22 @@ sub parse_java_jdk_release {
 		} else {
 			$release_hr->{j2se_version_name} .= ' GA';
 		}
+	} elsif ($release_name =~ m/^jdk-([0-9]+)\.([0-9]+)\.([0-9]+)(\.([0-9]+))?_linux-(i586|x64|amd64|arm-vfp-hflt)_bin.tar.gz$/ms) {
+		$release_hr->{j2se_arch} = $6;
+		$release_hr->{j2se_release} = $1;
+		$release_hr->{j2se_update} = $3;
+		$release_hr->{j2se_interim} = $2;
+		$release_hr->{j2se_patch} = $5;
+		$release_hr->{j2se_version} = $release_hr->{j2se_release}.'.'.
+			$release_hr->{j2se_interim}.'.'.
+			$release_hr->{j2se_update};
+		$release_hr->{j2se_version_name} = $release_hr->{j2se_release};
+		if ($release_hr->{j2se_update}) {
+			$release_hr->{j2se_version_name}
+				.= ' Update '.$release_hr->{j2se_update};
+		} else {
+			$release_hr->{j2se_version_name} .= ' GA';
+		}
 	} else {
 		err "Unsupported release.",
 			'release_name', $release_name;
@@ -49,7 +65,7 @@ __END__
 
 =head1 NAME
 
-Java-Release - Parse Java release archive.
+Java::Release - Parse Java release archive.
 
 =head1 SYNOPSIS
 
@@ -123,6 +139,6 @@ Thanks for L<java-package|https://salsa.debian.org/java-team/java-package.git> p
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
